Howard-music
============

    only support python3

    Baidu.KuGou.KuWo.QQ.163.MiGu API

--------------

安装
--------------

.. code:: console

    $ pip install h-music

帮助
--------------

.. code:: console

    $ h-music -h


更多
--------------

https://github.com/tt20050510/howard-music